/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.pluginresource;

import java.net.URL;
import java.util.List;

import org.tinygroup.fileresolver.FileProcessor;

public interface PluginResourceManager {
	
	/**
	 * 扫描指定url路径下的指定插件资源
	 * @param plugin
	 * @param url
	 */
	void resolve(Object plugin,URL[] url,ClassLoader loader);
	/**
	 * 删除指定url路径下的指定插件资源
	 * @param plugin
	 * @param url
	 */
	void deResolve(Object plugin,URL[] url,ClassLoader loader);
	/**
	 * 注册一个插件对象及其对应的该插件的资源扫描其
	 * PluginManager.add时调用
	 * @param pluginInfo
	 * @param processors 资源添加processors
	 * @param removeProcessor 资源删除processors
	 */
	void register(Object pluginInfo,List<FileProcessor> processors,List<FileProcessor> removeProcessor);
	/**
	 * 移除一个插件，在此处需要删除该插件的
	 * 由PluginManager.remove时调用
	 * @param pluginInfo
	 */
	void remove(Object pluginInfo);
	
	/**
	 * 扫描一个BU模块的资源
	 * @param loader bu模块对应的classloader
	 * @param list bu模块涉及的文件url
	 */
	void register(ClassLoader loader,URL[] urls);

	/**
	 * 移除一个BU模块的资源
	 * @param loader bu模块对应的classloader
	 * @param list bu模块设计的文件url
	 */
	void remove(ClassLoader loader,URL[] urls);
}
