/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.pluginresource.impl;

import java.net.URL;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.tinygroup.fileresolver.FileProcessor;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.pluginresource.PluginResourceManager;
import org.tinygroup.pluginresource.resolver.PluginResourceResolver;

public class PluginResourceManagerImpl implements PluginResourceManager {
	private Map<Object, List<FileProcessor>> addProcessors = new HashMap<Object, List<FileProcessor>>();
	private Map<Object, List<FileProcessor>> removeProcessors = new HashMap<Object, List<FileProcessor>>();
	private Map<ClassLoader, URL[]> resourceFiles = new HashMap<ClassLoader, URL[]>();
	private PluginResourceResolver resolver = new PluginResourceResolver();
	private Logger logger = LoggerFactory
			.getLogger(PluginResourceManagerImpl.class);

	public void register(Object pluginInfo, List<FileProcessor> processors,
			List<FileProcessor> removeProcessorList) {
		addProcessors.put(pluginInfo, processors);
		removeProcessors.put(pluginInfo, removeProcessorList);
		if (processors != null) { // 插件的资源添加处理器不为空
			for (ClassLoader loader : resourceFiles.keySet()) {
				URL[] urlArray = resourceFiles.get(loader);
				if (urlArray != null) { // BU的文件列表不为空
					resolver.resolve(urlArray, loader, processors);
				}

			}
		}

	}

	public void remove(Object pluginInfo) {
		addProcessors.remove(pluginInfo);
		List<FileProcessor> processors = removeProcessors.remove(pluginInfo);
		if (processors != null) { // 插件的资源添加处理器不为空
			for (ClassLoader loader : resourceFiles.keySet()) {
				URL[] urlArray = resourceFiles.get(loader);
				if (urlArray != null) { // BU的文件列表不为空
					resolver.resolve(urlArray, loader, processors);
				}

			}
		}
	}

	public void register(ClassLoader loader, URL[] urls) {
		resourceFiles.put(loader, urls);
		if (urls != null) {
			for (List<FileProcessor> processors : addProcessors.values()) {
				if (processors != null) {
					resolver.resolve(urls, loader, processors);
				}
			}
		}
	}

	public void remove(ClassLoader loader, URL[] urls) {
		resourceFiles.remove(loader);
		if (urls != null) {
			for (List<FileProcessor> processors : removeProcessors.values()) {
				if (processors != null) {
					resolver.resolve(urls, loader, processors);
				}
			}
		}
	}

	public List<FileProcessor> getResourceProcessor(Object plugin) {
		return addProcessors.get(plugin);
	}

	public void resolve(Object pluginInfo, URL[] url, ClassLoader loader) {
		List<FileProcessor> processors = addProcessors.get(pluginInfo);
		if (processors != null) { // 插件的资源添加处理器不为空
			if (url != null) { // BU的文件列表不为空
				resolver.resolve(url, loader, processors);
			}

		}
	}

	public void deResolve(Object pluginInfo, URL[] url, ClassLoader loader) {
		List<FileProcessor> processors = removeProcessors.get(pluginInfo);
		if (processors != null) { // 插件的资源添加处理器不为空
			if (url != null) { // BU的文件列表不为空
				resolver.resolve(url, loader, processors);
			}

		}
	}

}
